---
name: Bug report
about: Create a report to help us improve
title: ":bug: "
labels: bug
assignees: ""
---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

1. Import 'from pywaterflood import ...'
2. Load '....'
3. Run '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**System Info (please complete the following information):**

- OS: [e.g. Windows10, Ubuntu 22.04, etc]
- Python Version [e.g. 3.9]
- Python environment manager [e.g. system, venv, conda]
- Version [e.g. 0.3]

**Additional context**
Add any other context about the problem here.
